@@ -9,6 +9,8 @@ from dagster.api.snapshot_partition import (
     sync_get_external_partition_config_grpc,
     sync_get_external_partition_names,
     sync_get_external_partition_names_grpc,
+    sync_get_external_partition_set_execution_param_data,
+    sync_get_external_partition_set_execution_param_data_grpc,
     sync_get_external_partition_tags,
     sync_get_external_partition_tags_grpc,
 )
@@ -21,6 +23,10 @@ from dagster.api.snapshot_schedule import (
     sync_get_external_schedule_execution_data,
     sync_get_external_schedule_execution_data_grpc,
 )
+from dagster.api.snapshot_trigger import (
+    sync_get_external_trigger_execution_params,
+    sync_get_external_trigger_execution_params_grpc,
+)
 from dagster.core.definitions.reconstructable import ReconstructableRepository
 from dagster.core.execution.api import create_execution_plan, execute_plan, execute_run
 from dagster.core.host_representation import (
@@ -43,14 +49,18 @@ from dagster.core.snap.execution_plan_snapshot import (
 from dagster.core.storage.pipeline_run import PipelineRun
 from dagster.grpc.impl import (
     get_external_schedule_execution,
+    get_external_triggered_execution_params,
     get_partition_config,
     get_partition_names,
+    get_partition_set_execution_param_data,
     get_partition_tags,
 )
 from dagster.grpc.types import (
     ExternalScheduleExecutionArgs,
+    ExternalTriggeredExecutionArgs,
     PartitionArgs,
     PartitionNamesArgs,
+    PartitionSetExecutionParamArgs,
     ScheduleExecutionDataMode,
 )
 from dagster.utils.hosted_user_process import (
@@ -63,7 +73,7 @@ from .selector import PipelineSelector
 
 
 class RepositoryLocation(six.with_metaclass(ABCMeta)):
-    '''
+    """
     A RepositoryLocation represents a target containing user code which has a set of Dagster
     definition objects. A given location will contain some number of uniquely named
     RepositoryDefinitions, which therein contains Pipeline, Solid, and other definitions.
@@ -80,7 +90,7 @@ class RepositoryLocation(six.with_metaclass(ABCMeta)):
 
     We also allow for InProcessRepositoryLocation which actually loads the user-defined artifacts
     into process with the host tool. This is mostly for test scenarios.
-    '''
+    """
 
     @abstractmethod
     def get_repository(self, name):
@@ -145,6 +155,12 @@ class RepositoryLocation(six.with_metaclass(ABCMeta)):
     def get_external_partition_names(self, repository_handle, partition_set_name):
         pass
 
+    @abstractmethod
+    def get_external_partition_set_execution_param_data(
+        self, repository_handle, partition_set_name, partition_names
+    ):
+        pass
+
     @abstractmethod
     def get_external_schedule_execution_data(
         self, instance, repository_handle, schedule_name, schedule_execution_data_mode
@@ -152,7 +168,7 @@ class RepositoryLocation(six.with_metaclass(ABCMeta)):
         pass
 
     @abstractmethod
-    def create_reloaded_repository_location(self):
+    def get_external_triggered_execution_params(self, instance, repository_handle, trigger_name):
         pass
 
     @abstractproperty
@@ -162,7 +178,7 @@ class RepositoryLocation(six.with_metaclass(ABCMeta)):
     @staticmethod
     def from_handle(repository_location_handle):
         check.inst_param(
-            repository_location_handle, 'repository_location_handle', RepositoryLocationHandle
+            repository_location_handle, "repository_location_handle", RepositoryLocationHandle
         )
 
         if isinstance(repository_location_handle, InProcessRepositoryLocationHandle):
@@ -176,12 +192,15 @@ class RepositoryLocation(six.with_metaclass(ABCMeta)):
         ) or isinstance(repository_location_handle, ManagedGrpcPythonEnvRepositoryLocationHandle):
             return GrpcServerRepositoryLocation(repository_location_handle)
         else:
-            check.failed('Unsupported handle: {}'.format(repository_location_handle))
+            check.failed("Unsupported handle: {}".format(repository_location_handle))
+
+    def create_reloaded_repository_location(self):
+        return RepositoryLocation.from_handle(self.location_handle.create_reloaded_handle())
 
 
 class InProcessRepositoryLocation(RepositoryLocation):
     def __init__(self, recon_repo):
-        self._recon_repo = check.inst_param(recon_repo, 'recon_repo', ReconstructableRepository)
+        self._recon_repo = check.inst_param(recon_repo, "recon_repo", ReconstructableRepository)
         self._handle = RepositoryLocationHandle.create_in_process_location(recon_repo.pointer)
 
         repo_def = recon_repo.get_definition()
@@ -192,9 +211,6 @@ class InProcessRepositoryLocation(RepositoryLocation):
         )
         self._repositories = {self._external_repo.name: self._external_repo}
 
-    def create_reloaded_repository_location(self):
-        raise NotImplementedError('Not implemented for in-process')
-
     @property
     def is_reload_supported(self):
         return False
@@ -223,10 +239,10 @@ class InProcessRepositoryLocation(RepositoryLocation):
         return self._repositories
 
     def get_subset_external_pipeline_result(self, selector):
-        check.inst_param(selector, 'selector', PipelineSelector)
+        check.inst_param(selector, "selector", PipelineSelector)
         check.invariant(
             selector.location_name == self.name,
-            'PipelineSelector location_name mismatch, got {selector.location_name} expected {self.name}'.format(
+            "PipelineSelector location_name mismatch, got {selector.location_name} expected {self.name}".format(
                 self=self, selector=selector
             ),
         )
@@ -240,10 +256,10 @@ class InProcessRepositoryLocation(RepositoryLocation):
     def get_external_execution_plan(
         self, external_pipeline, run_config, mode, step_keys_to_execute
     ):
-        check.inst_param(external_pipeline, 'external_pipeline', ExternalPipeline)
-        check.dict_param(run_config, 'run_config')
-        check.str_param(mode, 'mode')
-        check.opt_list_param(step_keys_to_execute, 'step_keys_to_execute', of_type=str)
+        check.inst_param(external_pipeline, "external_pipeline", ExternalPipeline)
+        check.dict_param(run_config, "run_config")
+        check.str_param(mode, "mode")
+        check.opt_list_param(step_keys_to_execute, "step_keys_to_execute", of_type=str)
 
         return ExternalExecutionPlan(
             execution_plan_snapshot=snapshot_from_execution_plan(
@@ -271,11 +287,11 @@ class InProcessRepositoryLocation(RepositoryLocation):
         step_keys_to_execute,
         retries=None,
     ):
-        check.inst_param(instance, 'instance', DagsterInstance)
-        check.inst_param(external_pipeline, 'external_pipeline', ExternalPipeline)
-        check.dict_param(run_config, 'run_config')
-        check.inst_param(pipeline_run, 'pipeline_run', PipelineRun)
-        check.opt_list_param(step_keys_to_execute, 'step_keys_to_execute', of_type=str)
+        check.inst_param(instance, "instance", DagsterInstance)
+        check.inst_param(external_pipeline, "external_pipeline", ExternalPipeline)
+        check.dict_param(run_config, "run_config")
+        check.inst_param(pipeline_run, "pipeline_run", PipelineRun)
+        check.opt_list_param(step_keys_to_execute, "step_keys_to_execute", of_type=str)
 
         execution_plan = create_execution_plan(
             pipeline=self.get_reconstructable_pipeline(
@@ -297,9 +313,9 @@ class InProcessRepositoryLocation(RepositoryLocation):
     def execute_pipeline(
         self, instance, external_pipeline, pipeline_run,
     ):
-        check.inst_param(instance, 'instance', DagsterInstance)
-        check.inst_param(external_pipeline, 'external_pipeline', ExternalPipeline)
-        check.inst_param(pipeline_run, 'pipeline_run', PipelineRun)
+        check.inst_param(instance, "instance", DagsterInstance)
+        check.inst_param(external_pipeline, "external_pipeline", ExternalPipeline)
+        check.inst_param(pipeline_run, "pipeline_run", PipelineRun)
 
         pipeline = self.get_reconstructable_pipeline(
             external_pipeline.name
@@ -310,9 +326,9 @@ class InProcessRepositoryLocation(RepositoryLocation):
         return ExternalPipelineExecutionResult(event_list=execution_result.event_list)
 
     def get_external_partition_config(self, repository_handle, partition_set_name, partition_name):
-        check.inst_param(repository_handle, 'repository_handle', RepositoryHandle)
-        check.str_param(partition_set_name, 'partition_set_name')
-        check.str_param(partition_name, 'partition_name')
+        check.inst_param(repository_handle, "repository_handle", RepositoryHandle)
+        check.str_param(partition_set_name, "partition_set_name")
+        check.str_param(partition_name, "partition_name")
 
         args = PartitionArgs(
             repository_origin=repository_handle.get_origin(),
@@ -322,9 +338,9 @@ class InProcessRepositoryLocation(RepositoryLocation):
         return get_partition_config(args)
 
     def get_external_partition_tags(self, repository_handle, partition_set_name, partition_name):
-        check.inst_param(repository_handle, 'repository_handle', RepositoryHandle)
-        check.str_param(partition_set_name, 'partition_set_name')
-        check.str_param(partition_name, 'partition_name')
+        check.inst_param(repository_handle, "repository_handle", RepositoryHandle)
+        check.str_param(partition_set_name, "partition_set_name")
+        check.str_param(partition_name, "partition_name")
 
         args = PartitionArgs(
             repository_origin=repository_handle.get_origin(),
@@ -334,8 +350,8 @@ class InProcessRepositoryLocation(RepositoryLocation):
         return get_partition_tags(args)
 
     def get_external_partition_names(self, repository_handle, partition_set_name):
-        check.inst_param(repository_handle, 'repository_handle', RepositoryHandle)
-        check.str_param(partition_set_name, 'partition_set_name')
+        check.inst_param(repository_handle, "repository_handle", RepositoryHandle)
+        check.str_param(partition_set_name, "partition_set_name")
 
         args = PartitionNamesArgs(
             repository_origin=repository_handle.get_origin(), partition_set_name=partition_set_name
@@ -345,11 +361,11 @@ class InProcessRepositoryLocation(RepositoryLocation):
     def get_external_schedule_execution_data(
         self, instance, repository_handle, schedule_name, schedule_execution_data_mode
     ):
-        check.inst_param(instance, 'instance', DagsterInstance)
-        check.inst_param(repository_handle, 'repository_handle', RepositoryHandle)
-        check.str_param(schedule_name, 'schedule_name')
+        check.inst_param(instance, "instance", DagsterInstance)
+        check.inst_param(repository_handle, "repository_handle", RepositoryHandle)
+        check.str_param(schedule_name, "schedule_name")
         check.inst_param(
-            schedule_execution_data_mode, 'schedule_execution_data_mode', ScheduleExecutionDataMode
+            schedule_execution_data_mode, "schedule_execution_data_mode", ScheduleExecutionDataMode
         )
 
         repo_origin = repository_handle.get_origin()
@@ -362,13 +378,41 @@ class InProcessRepositoryLocation(RepositoryLocation):
         recon_repo = recon_repository_from_origin(repo_origin)
         return get_external_schedule_execution(recon_repo, args)
 
+    def get_external_triggered_execution_params(self, instance, repository_handle, trigger_name):
+        check.inst_param(instance, "instance", DagsterInstance)
+        check.inst_param(repository_handle, "repository_handle", RepositoryHandle)
+        check.str_param(trigger_name, "trigger_name")
+
+        repo_origin = repository_handle.get_origin()
+        recon_repo = recon_repository_from_origin(repo_origin)
+        args = ExternalTriggeredExecutionArgs(
+            instance_ref=instance.get_ref(),
+            repository_origin=repo_origin,
+            trigger_name=trigger_name,
+        )
+        return get_external_triggered_execution_params(recon_repo, args)
+
+    def get_external_partition_set_execution_param_data(
+        self, repository_handle, partition_set_name, partition_names
+    ):
+        check.inst_param(repository_handle, "repository_handle", RepositoryHandle)
+        check.str_param(partition_set_name, "partition_set_name")
+        check.list_param(partition_names, "partition_names", of_type=str)
+
+        args = PartitionSetExecutionParamArgs(
+            repository_origin=repository_handle.get_origin(),
+            partition_set_name=partition_set_name,
+            partition_names=partition_names,
+        )
+        return get_partition_set_execution_param_data(args)
+
 
 class GrpcServerRepositoryLocation(RepositoryLocation):
     def __init__(self, repository_location_handle):
         check.param_invariant(
             isinstance(repository_location_handle, GrpcServerRepositoryLocationHandle)
             or isinstance(repository_location_handle, ManagedGrpcPythonEnvRepositoryLocationHandle),
-            'repository_location_handle',
+            "repository_location_handle",
         )
 
         self._handle = repository_location_handle
@@ -379,15 +423,12 @@ class GrpcServerRepositoryLocation(RepositoryLocation):
 
         self.external_repositories = {repo.name: repo for repo in external_repositories_list}
 
-    def create_reloaded_repository_location(self):
-        return GrpcServerRepositoryLocation(self._handle)
-
     @property
     def is_reload_supported(self):
         return True
 
     def get_repository(self, name):
-        check.str_param(name, 'name')
+        check.str_param(name, "name")
         return self.external_repositories[name]
 
     def has_repository(self, name):
@@ -407,10 +448,10 @@ class GrpcServerRepositoryLocation(RepositoryLocation):
     def get_external_execution_plan(
         self, external_pipeline, run_config, mode, step_keys_to_execute
     ):
-        check.inst_param(external_pipeline, 'external_pipeline', ExternalPipeline)
-        check.dict_param(run_config, 'run_config')
-        check.str_param(mode, 'mode')
-        check.opt_list_param(step_keys_to_execute, 'step_keys_to_execute', of_type=str)
+        check.inst_param(external_pipeline, "external_pipeline", ExternalPipeline)
+        check.dict_param(run_config, "run_config")
+        check.str_param(mode, "mode")
+        check.opt_list_param(step_keys_to_execute, "step_keys_to_execute", of_type=str)
 
         execution_plan_snapshot_or_error = sync_get_external_execution_plan_grpc(
             api_client=self._handle.client,
@@ -439,26 +480,26 @@ class GrpcServerRepositoryLocation(RepositoryLocation):
         step_keys_to_execute,
         retries=None,
     ):
-        raise NotImplementedError('execute_plan is not implemented for grpc servers')
+        raise NotImplementedError("execute_plan is not implemented for grpc servers")
 
     def execute_pipeline(
         self, instance, external_pipeline, pipeline_run,
     ):
         from dagster.api.execute_run import sync_execute_run_grpc
 
-        check.inst_param(instance, 'instance', DagsterInstance)
-        check.inst_param(external_pipeline, 'external_pipeline', ExternalPipeline)
-        check.inst_param(pipeline_run, 'pipeline_run', PipelineRun)
+        check.inst_param(instance, "instance", DagsterInstance)
+        check.inst_param(external_pipeline, "external_pipeline", ExternalPipeline)
+        check.inst_param(pipeline_run, "pipeline_run", PipelineRun)
         event_list = sync_execute_run_grpc(
             self._handle.client, instance.get_ref(), external_pipeline.get_origin(), pipeline_run
         )
         return ExternalPipelineExecutionResult(event_list=event_list)
 
     def get_subset_external_pipeline_result(self, selector):
-        check.inst_param(selector, 'selector', PipelineSelector)
+        check.inst_param(selector, "selector", PipelineSelector)
         check.invariant(
             selector.location_name == self.name,
-            'PipelineSelector location_name mismatch, got {selector.location_name} expected {self.name}'.format(
+            "PipelineSelector location_name mismatch, got {selector.location_name} expected {self.name}".format(
                 self=self, selector=selector
             ),
         )
@@ -470,26 +511,26 @@ class GrpcServerRepositoryLocation(RepositoryLocation):
         )
 
     def get_external_partition_config(self, repository_handle, partition_set_name, partition_name):
-        check.inst_param(repository_handle, 'repository_handle', RepositoryHandle)
-        check.str_param(partition_set_name, 'partition_set_name')
-        check.str_param(partition_name, 'partition_name')
+        check.inst_param(repository_handle, "repository_handle", RepositoryHandle)
+        check.str_param(partition_set_name, "partition_set_name")
+        check.str_param(partition_name, "partition_name")
 
         return sync_get_external_partition_config_grpc(
             self._handle.client, repository_handle, partition_set_name, partition_name
         )
 
     def get_external_partition_tags(self, repository_handle, partition_set_name, partition_name):
-        check.inst_param(repository_handle, 'repository_handle', RepositoryHandle)
-        check.str_param(partition_set_name, 'partition_set_name')
-        check.str_param(partition_name, 'partition_name')
+        check.inst_param(repository_handle, "repository_handle", RepositoryHandle)
+        check.str_param(partition_set_name, "partition_set_name")
+        check.str_param(partition_name, "partition_name")
 
         return sync_get_external_partition_tags_grpc(
             self._handle.client, repository_handle, partition_set_name, partition_name
         )
 
     def get_external_partition_names(self, repository_handle, partition_set_name):
-        check.inst_param(repository_handle, 'repository_handle', RepositoryHandle)
-        check.str_param(partition_set_name, 'partition_set_name')
+        check.inst_param(repository_handle, "repository_handle", RepositoryHandle)
+        check.str_param(partition_set_name, "partition_set_name")
 
         return sync_get_external_partition_names_grpc(
             self._handle.client, repository_handle, partition_set_name
@@ -498,11 +539,11 @@ class GrpcServerRepositoryLocation(RepositoryLocation):
     def get_external_schedule_execution_data(
         self, instance, repository_handle, schedule_name, schedule_execution_data_mode
     ):
-        check.inst_param(instance, 'instance', DagsterInstance)
-        check.inst_param(repository_handle, 'repository_handle', RepositoryHandle)
-        check.str_param(schedule_name, 'schedule_name')
+        check.inst_param(instance, "instance", DagsterInstance)
+        check.inst_param(repository_handle, "repository_handle", RepositoryHandle)
+        check.str_param(schedule_name, "schedule_name")
         check.inst_param(
-            schedule_execution_data_mode, 'schedule_execution_data_mode', ScheduleExecutionDataMode
+            schedule_execution_data_mode, "schedule_execution_data_mode", ScheduleExecutionDataMode
         )
 
         return sync_get_external_schedule_execution_data_grpc(
@@ -513,27 +554,43 @@ class GrpcServerRepositoryLocation(RepositoryLocation):
             schedule_execution_data_mode,
         )
 
+    def get_external_triggered_execution_params(self, instance, repository_handle, trigger_name):
+        check.inst_param(instance, "instance", DagsterInstance)
+        check.inst_param(repository_handle, "repository_handle", RepositoryHandle)
+        check.str_param(trigger_name, "trigger_name")
+        return sync_get_external_trigger_execution_params_grpc(
+            self._handle.client, instance, repository_handle, trigger_name
+        )
+
+    def get_external_partition_set_execution_param_data(
+        self, repository_handle, partition_set_name, partition_names
+    ):
+        check.inst_param(repository_handle, "repository_handle", RepositoryHandle)
+        check.str_param(partition_set_name, "partition_set_name")
+        check.list_param(partition_names, "partition_names", of_type=str)
+
+        return sync_get_external_partition_set_execution_param_data_grpc(
+            self._handle.client, repository_handle, partition_set_name, partition_names
+        )
+
 
 class PythonEnvRepositoryLocation(RepositoryLocation):
     def __init__(self, repository_location_handle):
         self._handle = check.inst_param(
             repository_location_handle,
-            'repository_location_handle',
+            "repository_location_handle",
             PythonEnvRepositoryLocationHandle,
         )
 
         repo_list = sync_get_external_repositories(self._handle)
         self.external_repositories = {er.name: er for er in repo_list}
 
-    def create_reloaded_repository_location(self):
-        return PythonEnvRepositoryLocation(self._handle)
-
     @property
     def is_reload_supported(self):
         return True
 
     def get_repository(self, name):
-        check.str_param(name, 'name')
+        check.str_param(name, "name")
         return self.external_repositories[name]
 
     def has_repository(self, name):
@@ -555,10 +612,10 @@ class PythonEnvRepositoryLocation(RepositoryLocation):
     ):
         from dagster.api.snapshot_execution_plan import sync_get_external_execution_plan
 
-        check.inst_param(external_pipeline, 'external_pipeline', ExternalPipeline)
-        check.dict_param(run_config, 'run_config')
-        check.str_param(mode, 'mode')
-        check.opt_list_param(step_keys_to_execute, 'step_keys_to_execute', of_type=str)
+        check.inst_param(external_pipeline, "external_pipeline", ExternalPipeline)
+        check.dict_param(run_config, "run_config")
+        check.str_param(mode, "mode")
+        check.opt_list_param(step_keys_to_execute, "step_keys_to_execute", of_type=str)
 
         execution_plan_snapshot_or_error = sync_get_external_execution_plan(
             pipeline_origin=external_pipeline.get_origin(),
@@ -590,11 +647,11 @@ class PythonEnvRepositoryLocation(RepositoryLocation):
             is_repository_location_in_same_python_env(self.location_handle)
             and len(self.location_handle.repository_code_pointer_dict) == 1
         ):
-            check.inst_param(instance, 'instance', DagsterInstance)
-            check.inst_param(external_pipeline, 'external_pipeline', ExternalPipeline)
-            check.dict_param(run_config, 'run_config')
-            check.inst_param(pipeline_run, 'pipeline_run', PipelineRun)
-            check.opt_list_param(step_keys_to_execute, 'step_keys_to_execute', of_type=str)
+            check.inst_param(instance, "instance", DagsterInstance)
+            check.inst_param(external_pipeline, "external_pipeline", ExternalPipeline)
+            check.dict_param(run_config, "run_config")
+            check.inst_param(pipeline_run, "pipeline_run", PipelineRun)
+            check.opt_list_param(step_keys_to_execute, "step_keys_to_execute", of_type=str)
 
             pointer = next(iter(self.location_handle.repository_code_pointer_dict.values()))
             recon_repo = ReconstructableRepository(pointer)
@@ -617,9 +674,9 @@ class PythonEnvRepositoryLocation(RepositoryLocation):
             )
         else:
             raise NotImplementedError(
-                'execute_plan is currently only supported when the location is a python '
-                'environment with the exact same executable and when there is only a single '
-                'repository.'
+                "execute_plan is currently only supported when the location is a python "
+                "environment with the exact same executable and when there is only a single "
+                "repository."
             )
 
     def execute_pipeline(
@@ -627,9 +684,9 @@ class PythonEnvRepositoryLocation(RepositoryLocation):
     ):
         from dagster.api.execute_run import cli_api_execute_run
 
-        check.inst_param(instance, 'instance', DagsterInstance)
-        check.inst_param(external_pipeline, 'external_pipeline', ExternalPipeline)
-        check.inst_param(pipeline_run, 'pipeline_run', PipelineRun)
+        check.inst_param(instance, "instance", DagsterInstance)
+        check.inst_param(external_pipeline, "external_pipeline", ExternalPipeline)
+        check.inst_param(pipeline_run, "pipeline_run", PipelineRun)
 
         event_list = cli_api_execute_run(
             instance=instance,
@@ -642,10 +699,10 @@ class PythonEnvRepositoryLocation(RepositoryLocation):
     def get_subset_external_pipeline_result(self, selector):
         from dagster.api.snapshot_pipeline import sync_get_external_pipeline_subset
 
-        check.inst_param(selector, 'selector', PipelineSelector)
+        check.inst_param(selector, "selector", PipelineSelector)
         check.invariant(
             selector.location_name == self.name,
-            'PipelineSelector location_name mismatch, got {selector.location_name} expected {self.name}'.format(
+            "PipelineSelector location_name mismatch, got {selector.location_name} expected {self.name}".format(
                 self=self, selector=selector
             ),
         )
@@ -657,39 +714,56 @@ class PythonEnvRepositoryLocation(RepositoryLocation):
         )
 
     def get_external_partition_config(self, repository_handle, partition_set_name, partition_name):
-        check.inst_param(repository_handle, 'repository_handle', RepositoryHandle)
-        check.str_param(partition_set_name, 'partition_set_name')
-        check.str_param(partition_name, 'partition_name')
+        check.inst_param(repository_handle, "repository_handle", RepositoryHandle)
+        check.str_param(partition_set_name, "partition_set_name")
+        check.str_param(partition_name, "partition_name")
 
         return sync_get_external_partition_config(
             repository_handle, partition_set_name, partition_name
         )
 
     def get_external_partition_tags(self, repository_handle, partition_set_name, partition_name):
-        check.inst_param(repository_handle, 'repository_handle', RepositoryHandle)
-        check.str_param(partition_set_name, 'partition_set_name')
-        check.str_param(partition_name, 'partition_name')
+        check.inst_param(repository_handle, "repository_handle", RepositoryHandle)
+        check.str_param(partition_set_name, "partition_set_name")
+        check.str_param(partition_name, "partition_name")
 
         return sync_get_external_partition_tags(
             repository_handle, partition_set_name, partition_name
         )
 
     def get_external_partition_names(self, repository_handle, partition_set_name):
-        check.inst_param(repository_handle, 'repository_handle', RepositoryHandle)
-        check.str_param(partition_set_name, 'partition_set_name')
+        check.inst_param(repository_handle, "repository_handle", RepositoryHandle)
+        check.str_param(partition_set_name, "partition_set_name")
 
         return sync_get_external_partition_names(repository_handle, partition_set_name)
 
     def get_external_schedule_execution_data(
         self, instance, repository_handle, schedule_name, schedule_execution_data_mode
     ):
-        check.inst_param(instance, 'instance', DagsterInstance)
-        check.inst_param(repository_handle, 'repository_handle', RepositoryHandle)
-        check.str_param(schedule_name, 'schedule_name')
+        check.inst_param(instance, "instance", DagsterInstance)
+        check.inst_param(repository_handle, "repository_handle", RepositoryHandle)
+        check.str_param(schedule_name, "schedule_name")
         check.inst_param(
-            schedule_execution_data_mode, 'schedule_execution_data_mode', ScheduleExecutionDataMode
+            schedule_execution_data_mode, "schedule_execution_data_mode", ScheduleExecutionDataMode
         )
 
         return sync_get_external_schedule_execution_data(
             instance, repository_handle, schedule_name, schedule_execution_data_mode
         )
+
+    def get_external_triggered_execution_params(self, instance, repository_handle, trigger_name):
+        check.inst_param(instance, "instance", DagsterInstance)
+        check.inst_param(repository_handle, "repository_handle", RepositoryHandle)
+        check.str_param(trigger_name, "trigger_name")
+        return sync_get_external_trigger_execution_params(instance, repository_handle, trigger_name)
+
+    def get_external_partition_set_execution_param_data(
+        self, repository_handle, partition_set_name, partition_names
+    ):
+        check.inst_param(repository_handle, "repository_handle", RepositoryHandle)
+        check.str_param(partition_set_name, "partition_set_name")
+        check.list_param(partition_names, "partition_names", of_type=str)
+
+        return sync_get_external_partition_set_execution_param_data(
+            repository_handle, partition_set_name, partition_names
+        )
