@@ -12,6 +12,7 @@ from rx import Observable
 
 from dagster import check, seven
 from dagster.config import Field, Permissive
+from dagster.core.definitions.events import AssetKey
 from dagster.core.definitions.pipeline import PipelineDefinition, PipelineSubsetDefinition
 from dagster.core.errors import (
     DagsterInvalidConfigError,
@@ -35,28 +36,40 @@ from .ref import InstanceRef, compute_logs_directory
 # 'execution_date' used in Airflow operator execution and 'is_airflow_ingest_pipeline' determines
 # whether 'airflow_execution_date' is needed.
 # https://github.com/dagster-io/dagster/issues/2403
-AIRFLOW_EXECUTION_DATE_STR = 'airflow_execution_date'
-IS_AIRFLOW_INGEST_PIPELINE_STR = 'is_airflow_ingest_pipeline'
+AIRFLOW_EXECUTION_DATE_STR = "airflow_execution_date"
+IS_AIRFLOW_INGEST_PIPELINE_STR = "is_airflow_ingest_pipeline"
 
 
 def _is_dagster_home_set():
-    return bool(os.getenv('DAGSTER_HOME'))
+    return bool(os.getenv("DAGSTER_HOME"))
 
 
 def _dagster_home():
-    dagster_home_path = os.getenv('DAGSTER_HOME')
+    dagster_home_path = os.getenv("DAGSTER_HOME")
 
     if not dagster_home_path:
         raise DagsterInvariantViolationError(
-            'DAGSTER_HOME is not set, check is_dagster_home_set before invoking.'
+            "DAGSTER_HOME is not set, check is_dagster_home_set before invoking."
         )
 
-    return os.path.expanduser(dagster_home_path)
+    dagster_home_path = os.path.expanduser(dagster_home_path)
+
+    if not os.path.isabs(dagster_home_path):
+        raise DagsterInvariantViolationError(
+            "DAGSTER_HOME must be absolute path: {}".format(dagster_home_path)
+        )
+
+    if not (os.path.exists(dagster_home_path) and os.path.isdir(dagster_home_path)):
+        raise DagsterInvariantViolationError(
+            'DAGSTER_HOME "{}" is not a folder or does not exist!'.format(dagster_home_path)
+        )
+
+    return dagster_home_path
 
 
 def _check_run_equality(pipeline_run, candidate_run):
-    check.inst_param(pipeline_run, 'pipeline_run', PipelineRun)
-    check.inst_param(candidate_run, 'candidate_run', PipelineRun)
+    check.inst_param(pipeline_run, "pipeline_run", PipelineRun)
+    check.inst_param(candidate_run, "candidate_run", PipelineRun)
 
     field_diff = {}
     for field in pipeline_run._fields:
@@ -69,12 +82,12 @@ def _check_run_equality(pipeline_run, candidate_run):
 
 
 def _format_field_diff(field_diff):
-    return '\n'.join(
+    return "\n".join(
         [
             (
-                '    {field_name}:\n'
-                + '        Expected: {expected_value}\n'
-                + '        Received: {candidate_value}'
+                "    {field_name}:\n"
+                + "        Expected: {expected_value}\n"
+                + "        Received: {candidate_value}"
             ).format(
                 field_name=field_name,
                 expected_value=expected_value,
@@ -107,22 +120,24 @@ class _EventListenerLogHandler(logging.Handler):
             self._instance.handle_new_event(event)
 
         except Exception as e:  # pylint: disable=W0703
-            logging.critical('Error during instance event listen')
+            logging.critical("Error during instance event listen")
             logging.exception(str(e))
             raise
 
 
 class InstanceType(Enum):
-    PERSISTENT = 'PERSISTENT'
-    EPHEMERAL = 'EPHEMERAL'
+    PERSISTENT = "PERSISTENT"
+    EPHEMERAL = "EPHEMERAL"
 
 
 class DagsterInstance:
-    '''Core abstraction for managing Dagster's access to storage and other resources.
+    """Core abstraction for managing Dagster's access to storage and other resources.
 
-    Users should not directly instantiate this class; it is instantiated by internal machinery when
-    ``dagit`` and ``dagster-graphql`` load, based on the values in the ``dagster.yaml`` file in
-    ``$DAGSTER_HOME``. Configuration of this class should be done by setting values in that file.
+    Use DagsterInstance.get() to grab the current DagsterInstance which will load based on
+    the values in the ``dagster.yaml`` file in ``$DAGSTER_HOME`` if set, otherwise fallback
+    to using an ephemeral in-memory set of components.
+
+    Configuration of this class should be done by setting values in ``$DAGSTER_HOME/dagster.yaml``.
     For example, to use Postgres for run and event log storage, you can write a ``dagster.yaml``
     such as the following:
 
@@ -155,14 +170,12 @@ class DagsterInstance:
         run_launcher (Optional[RunLauncher]): Optionally, a run launcher may be used to enable
             a Dagster instance to launch pipeline runs, e.g. on a remote Kubernetes cluster, in
             addition to running them locally.
-        dagit_settings (Optional[Dict]): Specifies certain Dagit-specific, per-instance settings,
-            such as feature flags. These are set in the ``dagster.yaml`` under the key ``dagit``.
-        telemetry_settings (Optional[Dict]): Specifies certain telemetry-specific, per-instance
-            settings, such as whether it is enabled. These are set in the ``dagster.yaml`` under
-            the key ``telemetry``
+        settings (Optional[Dict]): Specifies certain per-instance settings,
+            such as feature flags. These are set in the ``dagster.yaml`` under a set of whitelisted
+            keys.
         ref (Optional[InstanceRef]): Used by internal machinery to pass instances across process
             boundaries.
-    '''
+    """
 
     _PROCESS_TEMPDIR = None
 
@@ -176,8 +189,7 @@ class DagsterInstance:
         schedule_storage=None,
         scheduler=None,
         run_launcher=None,
-        dagit_settings=None,
-        telemetry_settings=None,
+        settings=None,
         ref=None,
     ):
         from dagster.core.storage.compute_log_manager import ComputeLogManager
@@ -188,24 +200,25 @@ class DagsterInstance:
         from dagster.core.scheduler import Scheduler
         from dagster.core.launcher import RunLauncher
 
-        self._instance_type = check.inst_param(instance_type, 'instance_type', InstanceType)
+        self._instance_type = check.inst_param(instance_type, "instance_type", InstanceType)
         self._local_artifact_storage = check.inst_param(
-            local_artifact_storage, 'local_artifact_storage', LocalArtifactStorage
+            local_artifact_storage, "local_artifact_storage", LocalArtifactStorage
         )
-        self._event_storage = check.inst_param(event_storage, 'event_storage', EventLogStorage)
-        self._run_storage = check.inst_param(run_storage, 'run_storage', RunStorage)
+        self._event_storage = check.inst_param(event_storage, "event_storage", EventLogStorage)
+        self._run_storage = check.inst_param(run_storage, "run_storage", RunStorage)
         self._compute_log_manager = check.inst_param(
-            compute_log_manager, 'compute_log_manager', ComputeLogManager
+            compute_log_manager, "compute_log_manager", ComputeLogManager
         )
         self._schedule_storage = check.opt_inst_param(
-            schedule_storage, 'schedule_storage', ScheduleStorage
+            schedule_storage, "schedule_storage", ScheduleStorage
         )
-        self._scheduler = check.opt_inst_param(scheduler, 'scheduler', Scheduler)
-        self._run_launcher = check.inst_param(run_launcher, 'run_launcher', RunLauncher)
-        self._dagit_settings = check.opt_dict_param(dagit_settings, 'dagit_settings')
-        self._telemetry_settings = check.opt_dict_param(telemetry_settings, 'telemetry_settings')
+        self._scheduler = check.opt_inst_param(scheduler, "scheduler", Scheduler)
+        self._run_launcher = check.inst_param(run_launcher, "run_launcher", RunLauncher)
+        self._run_launcher.initialize(self)
 
-        self._ref = check.opt_inst_param(ref, 'ref', InstanceRef)
+        self._settings = check.opt_dict_param(settings, "settings")
+
+        self._ref = check.opt_inst_param(ref, "ref", InstanceRef)
 
         self._subscribers = defaultdict(list)
 
@@ -261,7 +274,7 @@ class DagsterInstance:
 
     @staticmethod
     def from_ref(instance_ref):
-        check.inst_param(instance_ref, 'instance_ref', InstanceRef)
+        check.inst_param(instance_ref, "instance_ref", InstanceRef)
         return DagsterInstance(
             instance_type=InstanceType.PERSISTENT,
             local_artifact_storage=instance_ref.local_artifact_storage,
@@ -271,8 +284,7 @@ class DagsterInstance:
             schedule_storage=instance_ref.schedule_storage,
             scheduler=instance_ref.scheduler,
             run_launcher=instance_ref.run_launcher,
-            dagit_settings=instance_ref.dagit_settings,
-            telemetry_settings=instance_ref.telemetry_settings,
+            settings=instance_ref.settings,
             ref=instance_ref,
         )
 
@@ -290,7 +302,7 @@ class DagsterInstance:
         if self._ref:
             return self._ref
 
-        check.failed('Can not produce an instance reference for {t}'.format(t=self))
+        check.failed("Can not produce an instance reference for {t}".format(t=self))
 
     @property
     def root_directory(self):
@@ -303,39 +315,35 @@ class DagsterInstance:
         return DagsterInstance._PROCESS_TEMPDIR.name
 
     def _info(self, component):
-        prefix = '     '
+        prefix = "     "
         # ConfigurableClass may not have inst_data if it's a direct instantiation
         # which happens for ephemeral instances
         if isinstance(component, ConfigurableClass) and component.inst_data:
             return component.inst_data.info_str(prefix)
         if type(component) is dict:
             return prefix + yaml.dump(component, default_flow_style=False).replace(
-                '\n', '\n' + prefix
+                "\n", "\n" + prefix
             )
-        return '{}{}\n'.format(prefix, component.__class__.__name__)
+        return "{}{}\n".format(prefix, component.__class__.__name__)
 
     def info_str_for_component(self, component_name, component):
-        return '{component_name}:\n{component}\n'.format(
+        return "{component_name}:\n{component}\n".format(
             component_name=component_name, component=self._info(component)
         )
 
     def info_str(self):
 
-        dagit_settings = self._dagit_settings if self._dagit_settings else None
-        telemetry_settings = self._telemetry_settings if self._telemetry_settings else None
+        settings = self._settings if self._settings else None
 
         return (
-            'DagsterInstance components:\n\n'
-            '  Local Artifacts Storage:\n{artifact}\n'
-            '  Run Storage:\n{run}\n'
-            '  Event Log Storage:\n{event}\n'
-            '  Compute Log Manager:\n{compute}\n'
-            '  Schedule Storage:\n{schedule_storage}\n'
-            '  Scheduler:\n{scheduler}\n'
-            '  Run Launcher:\n{run_launcher}\n'
-            '  Dagit:\n{dagit}\n'
-            '  Telemetry:\n{telemetry}\n'
-            ''.format(
+            "local_artifact_storage:\n{artifact}\n"
+            "run_storage:\n{run}\n"
+            "event_log_storage:\n{event}\n"
+            "compute_logs:\n{compute}\n"
+            "schedule_storage:\n{schedule_storage}\n"
+            "scheduler:\n{scheduler}\n"
+            "run_launcher:\n{run_launcher}\n"
+            "".format(
                 artifact=self._info(self._local_artifact_storage),
                 run=self._info(self._run_storage),
                 event=self._info(self._event_storage),
@@ -343,8 +351,14 @@ class DagsterInstance:
                 schedule_storage=self._info(self._schedule_storage),
                 scheduler=self._info(self._scheduler),
                 run_launcher=self._info(self._run_launcher),
-                dagit=self._info(dagit_settings),
-                telemetry=self._info(telemetry_settings),
+            )
+            + "\n".join(
+                [
+                    "{settings_key}:\n{settings_value}".format(
+                        settings_key=settings_key, settings_value=self._info(settings_value)
+                    )
+                    for settings_key, settings_value in settings.items()
+                ]
             )
         )
 
@@ -372,10 +386,10 @@ class DagsterInstance:
     def compute_log_manager(self):
         return self._compute_log_manager
 
-    @property
-    def dagit_settings(self):
-        if self._dagit_settings:
-            return self._dagit_settings
+    def get_settings(self, settings_key):
+        check.str_param(settings_key, "settings_key")
+        if self._settings and settings_key in self._settings:
+            return self._settings.get(settings_key)
         return {}
 
     @property
@@ -385,24 +399,26 @@ class DagsterInstance:
 
         dagster_telemetry_enabled_default = True
 
-        if not self._telemetry_settings:
+        telemetry_settings = self.get_settings("telemetry")
+
+        if not telemetry_settings:
             return dagster_telemetry_enabled_default
 
-        if 'enabled' in self._telemetry_settings:
-            return self._telemetry_settings['enabled']
+        if "enabled" in telemetry_settings:
+            return telemetry_settings["enabled"]
         else:
             return dagster_telemetry_enabled_default
 
     def upgrade(self, print_fn=lambda _: None):
         with upgrading_instance(self):
 
-            print_fn('Updating run storage...')
+            print_fn("Updating run storage...")
             self._run_storage.upgrade()
 
-            print_fn('Updating event storage...')
+            print_fn("Updating event storage...")
             self._event_storage.upgrade()
 
-            print_fn('Updating schedule storage...')
+            print_fn("Updating schedule storage...")
             self._schedule_storage.upgrade()
 
     def dispose(self):
@@ -470,24 +486,24 @@ class DagsterInstance:
         from dagster.core.execution.plan.plan import ExecutionPlan
         from dagster.core.snap import snapshot_from_execution_plan
 
-        check.inst_param(pipeline_def, 'pipeline_def', PipelineDefinition)
-        check.opt_inst_param(execution_plan, 'execution_plan', ExecutionPlan)
+        check.inst_param(pipeline_def, "pipeline_def", PipelineDefinition)
+        check.opt_inst_param(execution_plan, "execution_plan", ExecutionPlan)
 
         # note that solids_to_execute is required to execute the solid subset, which is the
         # frozenset version of the previous solid_subset.
         # solid_selection is not required and will not be converted to solids_to_execute here.
         # i.e. this function doesn't handle solid queries.
         # solid_selection is only used to pass the user queries further down.
-        check.opt_set_param(solids_to_execute, 'solids_to_execute', of_type=str)
-        check.opt_list_param(solid_selection, 'solid_selection', of_type=str)
+        check.opt_set_param(solids_to_execute, "solids_to_execute", of_type=str)
+        check.opt_list_param(solid_selection, "solid_selection", of_type=str)
 
         if solids_to_execute:
             if isinstance(pipeline_def, PipelineSubsetDefinition):
                 # for the case when pipeline_def is created by ExecutablePipeline or ExternalPipeline
                 check.invariant(
                     solids_to_execute == pipeline_def.solids_to_execute,
-                    'Cannot create a PipelineRun from pipeline subset {pipeline_solids_to_execute} '
-                    'that conflicts with solids_to_execute arg {solids_to_execute}'.format(
+                    "Cannot create a PipelineRun from pipeline subset {pipeline_solids_to_execute} "
+                    "that conflicts with solids_to_execute arg {solids_to_execute}".format(
                         pipeline_solids_to_execute=str_format_list(pipeline_def.solids_to_execute),
                         solids_to_execute=str_format_list(solids_to_execute),
                     ),
@@ -510,7 +526,7 @@ class DagsterInstance:
             pipeline_name=pipeline_def.name,
             run_id=run_id,
             run_config=run_config,
-            mode=check.opt_str_param(mode, 'mode', default=pipeline_def.get_default_mode_name()),
+            mode=check.opt_str_param(mode, "mode", default=pipeline_def.get_default_mode_name()),
             solid_selection=solid_selection,
             solids_to_execute=solids_to_execute,
             step_keys_to_execute=step_keys_to_execute,
@@ -548,7 +564,28 @@ class DagsterInstance:
             if AIRFLOW_EXECUTION_DATE_STR not in tags:
                 tags[AIRFLOW_EXECUTION_DATE_STR] = get_current_datetime_in_utc().isoformat()
 
-        pipeline_run = PipelineRun(
+        check.invariant(
+            not (not pipeline_snapshot and execution_plan_snapshot),
+            "It is illegal to have an execution plan snapshot and not have a pipeline snapshot. "
+            "It is possible to have no execution plan snapshot since we persist runs "
+            "that do not successfully compile execution plans in the scheduled case.",
+        )
+
+        pipeline_snapshot_id = (
+            self._ensure_persisted_pipeline_snapshot(pipeline_snapshot, parent_pipeline_snapshot)
+            if pipeline_snapshot
+            else None
+        )
+
+        execution_plan_snapshot_id = (
+            self._ensure_persisted_execution_plan_snapshot(
+                execution_plan_snapshot, pipeline_snapshot_id, step_keys_to_execute
+            )
+            if execution_plan_snapshot and pipeline_snapshot_id
+            else None
+        )
+
+        return PipelineRun(
             pipeline_name=pipeline_name,
             run_id=run_id,
             run_config=run_config,
@@ -560,66 +597,88 @@ class DagsterInstance:
             tags=tags,
             root_run_id=root_run_id,
             parent_run_id=parent_run_id,
+            pipeline_snapshot_id=pipeline_snapshot_id,
+            execution_plan_snapshot_id=execution_plan_snapshot_id,
         )
 
-        if pipeline_snapshot is not None:
-            from dagster.core.snap import create_pipeline_snapshot_id
+    def _ensure_persisted_pipeline_snapshot(self, pipeline_snapshot, parent_pipeline_snapshot):
+        from dagster.core.snap import create_pipeline_snapshot_id, PipelineSnapshot
 
-            if pipeline_snapshot.lineage_snapshot:
-                if not self._run_storage.has_pipeline_snapshot(
-                    pipeline_snapshot.lineage_snapshot.parent_snapshot_id
-                ):
-                    check.invariant(
-                        create_pipeline_snapshot_id(parent_pipeline_snapshot)
-                        == pipeline_snapshot.lineage_snapshot.parent_snapshot_id,
-                        'Parent pipeline snapshot id out of sync with passed parent pipeline snapshot',
-                    )
+        check.inst_param(pipeline_snapshot, "pipeline_snapshot", PipelineSnapshot)
+        check.opt_inst_param(parent_pipeline_snapshot, "parent_pipeline_snapshot", PipelineSnapshot)
 
-                    returned_pipeline_snapshot_id = self._run_storage.add_pipeline_snapshot(
-                        parent_pipeline_snapshot
-                    )
-                    check.invariant(
-                        pipeline_snapshot.lineage_snapshot.parent_snapshot_id
-                        == returned_pipeline_snapshot_id
-                    )
-
-            pipeline_snapshot_id = create_pipeline_snapshot_id(pipeline_snapshot)
-            if not self._run_storage.has_pipeline_snapshot(pipeline_snapshot_id):
-                returned_pipeline_snapshot_id = self._run_storage.add_pipeline_snapshot(
-                    pipeline_snapshot
+        if pipeline_snapshot.lineage_snapshot:
+            if not self._run_storage.has_pipeline_snapshot(
+                pipeline_snapshot.lineage_snapshot.parent_snapshot_id
+            ):
+                check.invariant(
+                    create_pipeline_snapshot_id(parent_pipeline_snapshot)
+                    == pipeline_snapshot.lineage_snapshot.parent_snapshot_id,
+                    "Parent pipeline snapshot id out of sync with passed parent pipeline snapshot",
                 )
-                check.invariant(pipeline_snapshot_id == returned_pipeline_snapshot_id)
 
-            pipeline_run = pipeline_run.with_pipeline_snapshot_id(pipeline_snapshot_id)
+                returned_pipeline_snapshot_id = self._run_storage.add_pipeline_snapshot(
+                    parent_pipeline_snapshot
+                )
+                check.invariant(
+                    pipeline_snapshot.lineage_snapshot.parent_snapshot_id
+                    == returned_pipeline_snapshot_id
+                )
 
-        if execution_plan_snapshot is not None:
-            from dagster.core.snap import create_execution_plan_snapshot_id
+        pipeline_snapshot_id = create_pipeline_snapshot_id(pipeline_snapshot)
+        if not self._run_storage.has_pipeline_snapshot(pipeline_snapshot_id):
+            returned_pipeline_snapshot_id = self._run_storage.add_pipeline_snapshot(
+                pipeline_snapshot
+            )
+            check.invariant(pipeline_snapshot_id == returned_pipeline_snapshot_id)
 
-            check.invariant(execution_plan_snapshot.pipeline_snapshot_id == pipeline_snapshot_id)
+        return pipeline_snapshot_id
 
-            check.invariant(
-                set(step_keys_to_execute) == set(execution_plan_snapshot.step_keys_to_execute)
-                if step_keys_to_execute
-                else set(execution_plan_snapshot.step_keys_to_execute)
-                == set([step.key for step in execution_plan_snapshot.steps]),
-                'We encode step_keys_to_execute twice in our stack, unfortunately. This check '
-                'ensures that they are consistent. We check that step_keys_to_execute in the plan '
-                'matches the step_keys_to_execute params if it is set. If it is not, this indicates '
-                'a full execution plan, and so we verify that.',
+    def _ensure_persisted_execution_plan_snapshot(
+        self, execution_plan_snapshot, pipeline_snapshot_id, step_keys_to_execute
+    ):
+        from dagster.core.snap.execution_plan_snapshot import (
+            ExecutionPlanSnapshot,
+            create_execution_plan_snapshot_id,
+        )
+
+        check.inst_param(execution_plan_snapshot, "execution_plan_snapshot", ExecutionPlanSnapshot)
+        check.str_param(pipeline_snapshot_id, "pipeline_snapshot_id")
+        check.opt_list_param(step_keys_to_execute, "step_keys_to_execute", of_type=str)
+
+        check.invariant(
+            execution_plan_snapshot.pipeline_snapshot_id == pipeline_snapshot_id,
+            (
+                "Snapshot mismatch: Snapshot ID in execution plan snapshot is "
+                '"{ep_pipeline_snapshot_id}" and snapshot_id created in memory is '
+                '"{pipeline_snapshot_id}"'
+            ).format(
+                ep_pipeline_snapshot_id=execution_plan_snapshot.pipeline_snapshot_id,
+                pipeline_snapshot_id=pipeline_snapshot_id,
+            ),
+        )
+
+        check.invariant(
+            set(step_keys_to_execute) == set(execution_plan_snapshot.step_keys_to_execute)
+            if step_keys_to_execute
+            else set(execution_plan_snapshot.step_keys_to_execute)
+            == set([step.key for step in execution_plan_snapshot.steps]),
+            "We encode step_keys_to_execute twice in our stack, unfortunately. This check "
+            "ensures that they are consistent. We check that step_keys_to_execute in the plan "
+            "matches the step_keys_to_execute params if it is set. If it is not, this indicates "
+            "a full execution plan, and so we verify that.",
+        )
+
+        execution_plan_snapshot_id = create_execution_plan_snapshot_id(execution_plan_snapshot)
+
+        if not self._run_storage.has_execution_plan_snapshot(execution_plan_snapshot_id):
+            returned_execution_plan_snapshot_id = self._run_storage.add_execution_plan_snapshot(
+                execution_plan_snapshot
             )
 
-            execution_plan_snapshot_id = create_execution_plan_snapshot_id(execution_plan_snapshot)
+            check.invariant(execution_plan_snapshot_id == returned_execution_plan_snapshot_id)
 
-            if not self._run_storage.has_execution_plan_snapshot(execution_plan_snapshot_id):
-                returned_execution_plan_snapshot_id = self._run_storage.add_execution_plan_snapshot(
-                    execution_plan_snapshot
-                )
-
-                check.invariant(execution_plan_snapshot_id == returned_execution_plan_snapshot_id)
-
-            pipeline_run = pipeline_run.with_execution_plan_snapshot_id(execution_plan_snapshot_id)
-
-        return pipeline_run
+        return execution_plan_snapshot_id
 
     def create_run(
         self,
@@ -708,8 +767,8 @@ class DagsterInstance:
 
             if field_diff:
                 raise DagsterRunConflict(
-                    'Found conflicting existing run with same id {run_id}. Runs differ in:'
-                    '\n{field_diff}'.format(
+                    "Found conflicting existing run with same id {run_id}. Runs differ in:"
+                    "\n{field_diff}".format(
                         run_id=pipeline_run.run_id, field_diff=_format_field_diff(field_diff),
                     ),
                 )
@@ -729,6 +788,9 @@ class DagsterInstance:
     def handle_run_event(self, run_id, event):
         return self._run_storage.handle_run_event(run_id, event)
 
+    def add_run_tags(self, run_id, new_tags):
+        return self._run_storage.add_run_tags(run_id, new_tags)
+
     def has_run(self, run_id):
         return self._run_storage.has_run(run_id)
 
@@ -760,10 +822,46 @@ class DagsterInstance:
     def watch_event_logs(self, run_id, cursor, cb):
         return self._event_storage.watch(run_id, cursor, cb)
 
+    # asset storage
+
+    @property
+    def is_asset_aware(self):
+        return self._event_storage.is_asset_aware
+
+    def check_asset_aware(self):
+        check.invariant(
+            self.is_asset_aware,
+            (
+                "Asset queries can only be performed on instances with asset-aware event log "
+                "storage. Use `instance.is_asset_aware` to verify that the instance is configured "
+                "with an EventLogStorage that implements `AssetAwareEventLogStorage`"
+            ),
+        )
+
+    def all_asset_keys(self):
+        self.check_asset_aware()
+        return self._event_storage.get_all_asset_keys()
+
+    def events_for_asset_key(self, asset_key, cursor=None, limit=None):
+        check.inst_param(asset_key, "asset_key", AssetKey)
+        self.check_asset_aware()
+        return self._event_storage.get_asset_events(asset_key, cursor, limit)
+
+    def run_ids_for_asset_key(self, asset_key):
+        check.inst_param(asset_key, "asset_key", AssetKey)
+        self.check_asset_aware()
+        return self._event_storage.get_asset_run_ids(asset_key)
+
+    def wipe_assets(self, asset_keys):
+        check.list_param(asset_keys, "asset_keys", of_type=AssetKey)
+        self.check_asset_aware()
+        for asset_key in asset_keys:
+            self._event_storage.wipe_asset(asset_key)
+
     # event subscriptions
 
     def get_logger(self):
-        logger = logging.Logger('__event_listener')
+        logger = logging.Logger("__event_listener")
         logger.addHandler(_EventListenerLogHandler(self))
         logger.setLevel(10)
         return logger
@@ -785,17 +883,17 @@ class DagsterInstance:
     def report_engine_event(
         self, message, pipeline_run, engine_event_data=None, cls=None, step_key=None,
     ):
-        '''
+        """
         Report a EngineEvent that occurred outside of a pipeline execution context.
-        '''
+        """
         from dagster.core.events import EngineEventData, DagsterEvent, DagsterEventType
         from dagster.core.events.log import DagsterEventRecord
 
-        check.class_param(cls, 'cls')
-        check.str_param(message, 'message')
-        check.inst_param(pipeline_run, 'pipeline_run', PipelineRun)
+        check.class_param(cls, "cls")
+        check.str_param(message, "message")
+        check.inst_param(pipeline_run, "pipeline_run", PipelineRun)
         engine_event_data = check.opt_inst_param(
-            engine_event_data, 'engine_event_data', EngineEventData, EngineEventData([]),
+            engine_event_data, "engine_event_data", EngineEventData, EngineEventData([]),
         )
 
         if cls:
@@ -830,9 +928,14 @@ class DagsterInstance:
         from dagster.core.events import DagsterEvent, DagsterEventType
         from dagster.core.events.log import DagsterEventRecord
 
-        check.inst_param(pipeline_run, 'pipeline_run', PipelineRun)
+        check.inst_param(pipeline_run, "pipeline_run", PipelineRun)
         message = "This pipeline run has been marked as failed from outside the execution context"
 
+        dagster_event = DagsterEvent(
+            event_type_value=DagsterEventType.PIPELINE_FAILURE.value,
+            pipeline_name=pipeline_run.pipeline_name,
+            message=message,
+        )
         event_record = DagsterEventRecord(
             message=message,
             user_message=message,
@@ -841,13 +944,10 @@ class DagsterInstance:
             run_id=pipeline_run.run_id,
             error_info=None,
             timestamp=time.time(),
-            dagster_event=DagsterEvent(
-                event_type_value=DagsterEventType.PIPELINE_FAILURE.value,
-                pipeline_name=pipeline_run.pipeline_name,
-                message=message,
-            ),
+            dagster_event=dagster_event,
         )
         self.handle_new_event(event_record)
+        return dagster_event
 
     # directories
 
@@ -863,7 +963,7 @@ class DagsterInstance:
     # Run launcher
 
     def launch_run(self, run_id, external_pipeline):
-        '''Launch a pipeline run.
+        """Launch a pipeline run.
 
         This method delegates to the ``RunLauncher``, if any, configured on the instance, and will
         call its implementation of ``RunLauncher.launch_run()`` to begin the execution of the
@@ -873,7 +973,7 @@ class DagsterInstance:
 
         Args:
             run_id (str): The id of the run the launch.
-        '''
+        """
         run = self.get_run_by_id(run_id)
         return self._run_launcher.launch_run(self, run, external_pipeline=external_pipeline)
 
@@ -929,7 +1029,8 @@ class DagsterInstance:
                     "status": schedule_state.status.value,
                     "cron_schedule": schedule_state.cron_schedule,
                     "python_path": schedule_state.pipeline_origin.executable_path,
-                    "repository_pointer": schedule_state.pipeline_origin.get_repo_pointer().describe(),
+                    "pipeline_origin_id": schedule_state.pipeline_origin.get_id(),
+                    "repository_pointer": schedule_state.pipeline_origin.get_repo_cli_args(),
                     "schedule_origin_id": schedule_state.schedule_origin_id,
                     "repository_origin_id": schedule_state.repository_origin_id,
                 }
@@ -938,7 +1039,7 @@ class DagsterInstance:
             schedules.append(yaml.safe_dump(schedule_info, default_flow_style=False))
 
         return SchedulerDebugInfo(
-            scheduler_config_info=self.info_str_for_component('Scheduler', self.scheduler),
+            scheduler_config_info=self.info_str_for_component("Scheduler", self.scheduler),
             scheduler_info=self.scheduler.debug_info(),
             schedule_storage=schedules,
             errors=errors,
