@@ -1,10 +1,10 @@
-'''Workhorse functions for individual API requests.'''
+"""Workhorse functions for individual API requests."""
 
 import os
 import sys
 
 from dagster import check
-from dagster.core.definitions import ScheduleExecutionContext
+from dagster.core.definitions import ScheduleExecutionContext, TriggeredExecutionContext
 from dagster.core.definitions.reconstructable import (
     ReconstructablePipeline,
     ReconstructableRepository,
@@ -14,12 +14,15 @@ from dagster.core.errors import (
     DagsterSubprocessError,
     PartitionExecutionError,
     ScheduleExecutionError,
+    TriggeredExecutionError,
     user_code_error_boundary,
 )
 from dagster.core.events import EngineEventData
 from dagster.core.execution.api import create_execution_plan, execute_run_iterator
 from dagster.core.host_representation import external_pipeline_data_from_def
 from dagster.core.host_representation.external_data import (
+    ExternalExecutionParamsData,
+    ExternalExecutionParamsErrorData,
     ExternalPartitionConfigData,
     ExternalPartitionExecutionErrorData,
     ExternalPartitionExecutionParamData,
@@ -39,6 +42,7 @@ from dagster.core.storage.pipeline_run import PipelineRun
 from dagster.grpc.types import (
     ExecutionPlanSnapshotArgs,
     ExternalScheduleExecutionArgs,
+    ExternalTriggeredExecutionArgs,
     PartitionArgs,
     PartitionNamesArgs,
     ScheduleExecutionDataMode,
@@ -53,36 +57,36 @@ from .types import ExecuteRunArgs, ExternalScheduleExecutionArgs, PartitionSetEx
 
 
 class RunInSubprocessComplete:
-    '''Sentinel passed over multiprocessing Queue when subprocess is complete'''
+    """Sentinel passed over multiprocessing Queue when subprocess is complete"""
 
 
 class StartRunInSubprocessSuccessful:
-    '''Sentinel passed over multiprocessing Queue when launch is successful in subprocess.'''
+    """Sentinel passed over multiprocessing Queue when launch is successful in subprocess."""
 
 
 def _core_execute_run(recon_pipeline, pipeline_run, instance):
-    check.inst_param(recon_pipeline, 'recon_pipeline', ReconstructablePipeline)
-    check.inst_param(pipeline_run, 'pipeline_run', PipelineRun)
-    check.inst_param(instance, 'instance', DagsterInstance)
+    check.inst_param(recon_pipeline, "recon_pipeline", ReconstructablePipeline)
+    check.inst_param(pipeline_run, "pipeline_run", PipelineRun)
+    check.inst_param(instance, "instance", DagsterInstance)
 
     try:
         for event in execute_run_iterator(recon_pipeline, pipeline_run, instance):
             yield event
     except DagsterSubprocessError as err:
         if not all(
-            [err_info.cls_name == 'KeyboardInterrupt' for err_info in err.subprocess_error_infos]
+            [err_info.cls_name == "KeyboardInterrupt" for err_info in err.subprocess_error_infos]
         ):
             yield instance.report_engine_event(
-                'An exception was thrown during execution that is likely a framework error, '
-                'rather than an error in user code.',
+                "An exception was thrown during execution that is likely a framework error, "
+                "rather than an error in user code.",
                 pipeline_run,
                 EngineEventData.engine_error(serializable_error_info_from_exc_info(sys.exc_info())),
             )
             instance.report_run_failed(pipeline_run)
     except Exception:  # pylint: disable=broad-except
         yield instance.report_engine_event(
-            'An exception was thrown during execution that is likely a framework error, '
-            'rather than an error in user code.',
+            "An exception was thrown during execution that is likely a framework error, "
+            "rather than an error in user code.",
             pipeline_run,
             EngineEventData.engine_error(serializable_error_info_from_exc_info(sys.exc_info())),
         )
@@ -100,7 +104,7 @@ def _run_in_subprocess(
     start_termination_thread(termination_event)
     try:
         execute_run_args = deserialize_json_to_dagster_namedtuple(serialized_execute_run_args)
-        check.inst_param(execute_run_args, 'execute_run_args', ExecuteRunArgs)
+        check.inst_param(execute_run_args, "execute_run_args", ExecuteRunArgs)
 
         instance = DagsterInstance.from_ref(execute_run_args.instance_ref)
         pipeline_run = instance.get_run_by_id(execute_run_args.pipeline_run_id)
@@ -110,7 +114,7 @@ def _run_in_subprocess(
     except:  # pylint: disable=bare-except
         event = IPCErrorMessage(
             serializable_error_info=serializable_error_info_from_exc_info(sys.exc_info()),
-            message='Error during RPC setup for ExecuteRun',
+            message="Error during RPC setup for ExecuteRun",
         )
         subprocess_status_handler(event)
         subprocess_status_handler(RunInSubprocessComplete())
@@ -120,9 +124,9 @@ def _run_in_subprocess(
 
     run_event_handler(
         instance.report_engine_event(
-            'Started process for pipeline (pid: {pid}).'.format(pid=pid),
+            "Started process for pipeline (pid: {pid}).".format(pid=pid),
             pipeline_run,
-            EngineEventData.in_process(pid, marker_end='cli_api_subprocess_init'),
+            EngineEventData.in_process(pid, marker_end="cli_api_subprocess_init"),
         )
     )
 
@@ -135,7 +139,7 @@ def _run_in_subprocess(
     except KeyboardInterrupt:
         run_event_handler(
             instance.report_engine_event(
-                message='Pipeline execution terminated by interrupt', pipeline_run=pipeline_run,
+                message="Pipeline execution terminated by interrupt", pipeline_run=pipeline_run,
             )
         )
         raise
@@ -146,7 +150,7 @@ def _run_in_subprocess(
         if not closed:
             run_event_handler(
                 instance.report_engine_event(
-                    'Process for pipeline exited (pid: {pid}).'.format(pid=pid), pipeline_run,
+                    "Process for pipeline exited (pid: {pid}).".format(pid=pid), pipeline_run,
                 )
             )
         subprocess_status_handler(RunInSubprocessComplete())
@@ -177,7 +181,7 @@ def start_run_in_subprocess(
 
 
 def get_external_pipeline_subset_result(recon_pipeline, solid_selection):
-    check.inst_param(recon_pipeline, 'recon_pipeline', ReconstructablePipeline)
+    check.inst_param(recon_pipeline, "recon_pipeline", ReconstructablePipeline)
 
     if solid_selection:
         try:
@@ -196,11 +200,11 @@ def get_external_pipeline_subset_result(recon_pipeline, solid_selection):
 
 def get_external_schedule_execution(recon_repo, external_schedule_execution_args):
     check.inst_param(
-        recon_repo, 'recon_repo', ReconstructableRepository,
+        recon_repo, "recon_repo", ReconstructableRepository,
     )
     check.inst_param(
         external_schedule_execution_args,
-        'external_schedule_execution_args',
+        "external_schedule_execution_args",
         ExternalScheduleExecutionArgs,
     )
 
@@ -213,8 +217,8 @@ def get_external_schedule_execution(recon_repo, external_schedule_execution_args
     try:
         with user_code_error_boundary(
             ScheduleExecutionError,
-            lambda: 'Error occurred during the execution of should_execute for schedule '
-            '{schedule_name}'.format(schedule_name=schedule_def.name),
+            lambda: "Error occurred during the execution of should_execute for schedule "
+            "{schedule_name}".format(schedule_name=schedule_def.name),
         ):
             should_execute = None
             if schedule_execution_data_mode == ScheduleExecutionDataMode.LAUNCH_SCHEDULED_EXECUTION:
@@ -226,15 +230,15 @@ def get_external_schedule_execution(recon_repo, external_schedule_execution_args
 
         with user_code_error_boundary(
             ScheduleExecutionError,
-            lambda: 'Error occurred during the execution of run_config_fn for schedule '
-            '{schedule_name}'.format(schedule_name=schedule_def.name),
+            lambda: "Error occurred during the execution of run_config_fn for schedule "
+            "{schedule_name}".format(schedule_name=schedule_def.name),
         ):
             run_config = schedule_def.get_run_config(schedule_context)
 
         with user_code_error_boundary(
             ScheduleExecutionError,
-            lambda: 'Error occurred during the execution of tags_fn for schedule '
-            '{schedule_name}'.format(schedule_name=schedule_def.name),
+            lambda: "Error occurred during the execution of tags_fn for schedule "
+            "{schedule_name}".format(schedule_name=schedule_def.name),
         ):
             tags = schedule_def.get_tags(schedule_context)
 
@@ -247,8 +251,55 @@ def get_external_schedule_execution(recon_repo, external_schedule_execution_args
         )
 
 
+def get_external_triggered_execution_params(recon_repo, external_triggered_execution_args):
+    check.inst_param(recon_repo, "recon_repo", ReconstructableRepository)
+    check.inst_param(
+        external_triggered_execution_args,
+        "external_triggered_execution_args",
+        ExternalTriggeredExecutionArgs,
+    )
+    definition = recon_repo.get_definition()
+    triggered_execution_def = definition.get_triggered_execution_def(
+        external_triggered_execution_args.trigger_name
+    )
+    instance = DagsterInstance.from_ref(external_triggered_execution_args.instance_ref)
+    context = TriggeredExecutionContext(instance)
+
+    try:
+        with user_code_error_boundary(
+            TriggeredExecutionError,
+            lambda: "Error occured during the execution of should_execute_fn for triggered "
+            "execution {name}".format(name=triggered_execution_def.name),
+        ):
+            should_execute = triggered_execution_def.should_execute(context)
+            if not should_execute:
+                return ExternalExecutionParamsData(run_config=None, tags=None, should_execute=False)
+
+        with user_code_error_boundary(
+            TriggeredExecutionError,
+            lambda: "Error occured during the execution of run_config_fn for triggered "
+            "execution {name}".format(name=triggered_execution_def.name),
+        ):
+            run_config = triggered_execution_def.get_run_config(context)
+
+        with user_code_error_boundary(
+            TriggeredExecutionError,
+            lambda: "Error occured during the execution of tags_fn for triggered "
+            "execution {name}".format(name=triggered_execution_def.name),
+        ):
+            tags = triggered_execution_def.get_tags(context)
+
+        return ExternalExecutionParamsData(
+            run_config=run_config, tags=tags, should_execute=should_execute
+        )
+    except TriggeredExecutionError:
+        return ExternalExecutionParamsErrorData(
+            serializable_error_info_from_exc_info(sys.exc_info())
+        )
+
+
 def get_partition_config(args):
-    check.inst_param(args, 'args', PartitionArgs)
+    check.inst_param(args, "args", PartitionArgs)
     recon_repo = recon_repository_from_origin(args.repository_origin)
     definition = recon_repo.get_definition()
     partition_set_def = definition.get_partition_set_def(args.partition_set_name)
@@ -256,8 +307,8 @@ def get_partition_config(args):
     try:
         with user_code_error_boundary(
             PartitionExecutionError,
-            lambda: 'Error occurred during the evaluation of the `run_config_for_partition` '
-            'function for partition set {partition_set_name}'.format(
+            lambda: "Error occurred during the evaluation of the `run_config_for_partition` "
+            "function for partition set {partition_set_name}".format(
                 partition_set_name=partition_set_def.name
             ),
         ):
@@ -270,15 +321,15 @@ def get_partition_config(args):
 
 
 def get_partition_names(args):
-    check.inst_param(args, 'args', PartitionNamesArgs)
+    check.inst_param(args, "args", PartitionNamesArgs)
     recon_repo = recon_repository_from_origin(args.repository_origin)
     definition = recon_repo.get_definition()
     partition_set_def = definition.get_partition_set_def(args.partition_set_name)
     try:
         with user_code_error_boundary(
             PartitionExecutionError,
-            lambda: 'Error occurred during the execution of the partition generation function for '
-            'partition set {partition_set_name}'.format(partition_set_name=partition_set_def.name),
+            lambda: "Error occurred during the execution of the partition generation function for "
+            "partition set {partition_set_name}".format(partition_set_name=partition_set_def.name),
         ):
             return ExternalPartitionNamesData(
                 partition_names=partition_set_def.get_partition_names()
@@ -290,7 +341,7 @@ def get_partition_names(args):
 
 
 def get_partition_tags(args):
-    check.inst_param(args, 'args', PartitionArgs)
+    check.inst_param(args, "args", PartitionArgs)
     recon_repo = recon_repository_from_origin(args.repository_origin)
     definition = recon_repo.get_definition()
     partition_set_def = definition.get_partition_set_def(args.partition_set_name)
@@ -298,8 +349,8 @@ def get_partition_tags(args):
     try:
         with user_code_error_boundary(
             PartitionExecutionError,
-            lambda: 'Error occurred during the evaluation of the `tags_for_partition` function for '
-            'partition set {partition_set_name}'.format(partition_set_name=partition_set_def.name),
+            lambda: "Error occurred during the evaluation of the `tags_for_partition` function for "
+            "partition set {partition_set_name}".format(partition_set_name=partition_set_def.name),
         ):
             tags = partition_set_def.tags_for_partition(partition)
             return ExternalPartitionTagsData(name=partition.name, tags=tags)
@@ -310,8 +361,8 @@ def get_partition_tags(args):
 
 
 def get_external_execution_plan_snapshot(recon_pipeline, args):
-    check.inst_param(recon_pipeline, 'recon_pipeline', ReconstructablePipeline)
-    check.inst_param(args, 'args', ExecutionPlanSnapshotArgs)
+    check.inst_param(recon_pipeline, "recon_pipeline", ReconstructablePipeline)
+    check.inst_param(args, "args", ExecutionPlanSnapshotArgs)
 
     try:
         pipeline = (
@@ -336,15 +387,15 @@ def get_external_execution_plan_snapshot(recon_pipeline, args):
 
 
 def get_partition_set_execution_param_data(args):
-    check.inst_param(args, 'args', PartitionSetExecutionParamArgs)
+    check.inst_param(args, "args", PartitionSetExecutionParamArgs)
     recon_repo = recon_repository_from_origin(args.repository_origin)
     repo_definition = recon_repo.get_definition()
     partition_set_def = repo_definition.get_partition_set_def(args.partition_set_name)
     try:
         with user_code_error_boundary(
             PartitionExecutionError,
-            lambda: 'Error occurred during the partition generation for partition set '
-            '{partition_set_name}'.format(partition_set_name=partition_set_def.name),
+            lambda: "Error occurred during the partition generation for partition set "
+            "{partition_set_name}".format(partition_set_name=partition_set_def.name),
         ):
             all_partitions = partition_set_def.get_partitions()
         partitions = [
@@ -356,8 +407,8 @@ def get_partition_set_execution_param_data(args):
 
             def _error_message_fn(partition_set_name, partition_name):
                 return lambda: (
-                    'Error occurred during the partition config and tag generation for '
-                    'partition set {partition_set_name}::{partition_name}'.format(
+                    "Error occurred during the partition config and tag generation for "
+                    "partition set {partition_set_name}::{partition_name}".format(
                         partition_set_name=partition_set_name, partition_name=partition_name
                     )
                 )
